@@ -28,26 +28,29 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <QListView>
 #include <QMenu>
 #include <QMimeData>
+#include <QShortcut>
 
 // KDE
-#include <KAction>
 #include <KActionCollection>
 #include <KActionCategory>
-#include <KDebug>
 #include <KFileItem>
 #include <KFileItemActions>
-#include <kio/paste.h>
-#include <KLocale>
-#include <KMimeTypeTrader>
+#include <KIO/Paste>
+#include <KIO/PasteJob>
+#include <KIO/RestoreJob>
+#include <KIO/JobUiDelegate>
+#include <KIOCore/KFileItemListProperties>
+#include <KJobWidgets>
+#include <KLocalizedString>
+#include <KNewFileMenu>
 #include <KOpenWithDialog>
 #include <KPropertiesDialog>
 #include <KRun>
 #include <KService>
 #include <KXMLGUIClient>
-
-// libkonq
-#include <konqmimedata.h>
-#include <konq_operations.h>
+#include <KUrlMimeData>
+#include <KFileItemActions>
+#include <KFileItemListProperties>
 
 // Local
 #include <lib/contextmanager.h>
@@ -65,33 +68,34 @@ struct FileOpsContextManagerItemPrivate
     QListView* mThumbnailView;
     KXMLGUIClient* mXMLGUIClient;
     SideBarGroup* mGroup;
-    KAction* mCutAction;
-    KAction* mCopyAction;
-    KAction* mPasteAction;
-    KAction* mCopyToAction;
-    KAction* mMoveToAction;
-    KAction* mLinkToAction;
-    KAction* mRenameAction;
-    KAction* mTrashAction;
-    KAction* mDelAction;
-    KAction* mRestoreAction;
-    KAction* mShowPropertiesAction;
-    KAction* mCreateFolderAction;
-    KAction* mOpenWithAction;
+    QAction * mCutAction;
+    QAction * mCopyAction;
+    QAction * mPasteAction;
+    QAction * mCopyToAction;
+    QAction * mMoveToAction;
+    QAction * mLinkToAction;
+    QAction * mRenameAction;
+    QAction * mTrashAction;
+    QAction * mDelAction;
+    QAction * mRestoreAction;
+    QAction * mShowPropertiesAction;
+    QAction * mCreateFolderAction;
+    QAction * mOpenWithAction;
     QList<QAction*> mRegularFileActionList;
     QList<QAction*> mTrashFileActionList;
     KService::List mServiceList;
+    KNewFileMenu * mNewFileMenu;
     bool mInTrash;
 
-    KUrl::List urlList() const
+    QList<QUrl> urlList() const
     {
-        KUrl::List urlList;
+        QList<QUrl> urlList;
 
         KFileItemList list = q->contextManager()->selectedFileItemList();
         if (list.count() > 0) {
             urlList = list.urlList();
         } else {
-            KUrl url = q->contextManager()->currentUrl();
+            QUrl url = q->contextManager()->currentUrl();
             Q_ASSERT(url.isValid());
             urlList << url;
         }
@@ -120,11 +124,11 @@ struct FileOpsContextManagerItemPrivate
     {
         QMimeData* mimeData = new QMimeData;
         KFileItemList list = q->contextManager()->selectedFileItemList();
-        list.urlList().populateMimeData(mimeData);
+        mimeData->setUrls(list.urlList());
         return mimeData;
     }
 
-    KUrl pasteTargetUrl() const
+    QUrl pasteTargetUrl() const
     {
         // If only one folder is selected, paste inside it, otherwise paste in
         // current
@@ -139,7 +143,7 @@ struct FileOpsContextManagerItemPrivate
 
 static QAction* createSeparator(QObject* parent)
 {
-    QAction* action = new KAction(parent);
+    QAction* action = new QAction(parent);
     action->setSeparator(true);
     return action;
 }
@@ -156,10 +160,11 @@ FileOpsContextManagerItem::FileOpsContextManagerItem(ContextManager* manager, QL
     EventWatcher::install(d->mGroup, QEvent::Show, this, SLOT(updateSideBarContent()));
 
     d->mInTrash = false;
+    d->mNewFileMenu = new KNewFileMenu(Q_NULLPTR, QString(), this);
 
     connect(contextManager(), SIGNAL(selectionChanged()),
             SLOT(updateActions()));
-    connect(contextManager(), SIGNAL(currentDirUrlChanged(KUrl)),
+    connect(contextManager(), SIGNAL(currentDirUrlChanged(QUrl)),
             SLOT(updateActions()));
 
     KActionCategory* file = new KActionCategory(i18nc("@title actions category", "File"), actionCollection);
@@ -170,58 +175,56 @@ FileOpsContextManagerItem::FileOpsContextManagerItem(ContextManager* manager, QL
     // Copied from Dolphin:
     // need to remove shift+del from cut action, else the shortcut for deletejob
     // doesn't work
-    KShortcut cutShortcut = d->mCutAction->shortcut();
-    cutShortcut.remove(Qt::SHIFT + Qt::Key_Delete, KShortcut::KeepEmpty);
-    d->mCutAction->setShortcut(cutShortcut);
+    //KF5TODO
+//     d->mCopyAction->setShortcut(QKeySequence());
 
     d->mCopyAction = edit->addAction(KStandardAction::Copy, this, SLOT(copy()));
     d->mPasteAction = edit->addAction(KStandardAction::Paste, this, SLOT(paste()));
 
     d->mCopyToAction = file->addAction("file_copy_to", this, SLOT(copyTo()));
     d->mCopyToAction->setText(i18nc("Verb", "Copy To..."));
-    d->mCopyToAction->setShortcut(Qt::Key_F7);
+    actionCollection->setDefaultShortcut(d->mCopyAction, Qt::Key_F7);
 
     d->mMoveToAction = file->addAction("file_move_to", this, SLOT(moveTo()));
     d->mMoveToAction->setText(i18nc("Verb", "Move To..."));
-    d->mMoveToAction->setShortcut(Qt::Key_F8);
+    actionCollection->setDefaultShortcut(d->mMoveToAction, Qt::Key_F8);
 
     d->mLinkToAction = file->addAction("file_link_to", this, SLOT(linkTo()));
     d->mLinkToAction->setText(i18nc("Verb: create link to the file where user wants", "Link To..."));
-    d->mLinkToAction->setShortcut(Qt::Key_F9);
+    actionCollection->setDefaultShortcut(d->mLinkToAction, Qt::Key_F9);
 
     d->mRenameAction = file->addAction("file_rename", this, SLOT(rename()));
     d->mRenameAction->setText(i18nc("Verb", "Rename..."));
-    d->mRenameAction->setShortcut(Qt::Key_F2);
+    d->mRenameAction->setIcon(QIcon::fromTheme("edit-rename"));
+    actionCollection->setDefaultShortcut(d->mRenameAction, Qt::Key_F2);
 
     d->mTrashAction = file->addAction("file_trash", this, SLOT(trash()));
     d->mTrashAction->setText(i18nc("Verb", "Trash"));
-    d->mTrashAction->setIcon(KIcon("user-trash"));
-    d->mTrashAction->setShortcut(Qt::Key_Delete);
+    d->mTrashAction->setIcon(QIcon::fromTheme("user-trash"));
+    actionCollection->setDefaultShortcut(d->mTrashAction, Qt::Key_Delete);
 
     d->mDelAction = file->addAction("file_delete", this, SLOT(del()));
     d->mDelAction->setText(i18n("Delete"));
-    d->mDelAction->setIcon(KIcon("edit-delete"));
-    d->mDelAction->setShortcut(QKeySequence(Qt::ShiftModifier | Qt::Key_Delete));
+    d->mDelAction->setIcon(QIcon::fromTheme("edit-delete"));
+    actionCollection->setDefaultShortcut(d->mDelAction, QKeySequence(Qt::ShiftModifier | Qt::Key_Delete));
 
     d->mRestoreAction = file->addAction("file_restore", this, SLOT(restore()));
     d->mRestoreAction->setText(i18n("Restore"));
 
     d->mShowPropertiesAction = file->addAction("file_show_properties", this, SLOT(showProperties()));
     d->mShowPropertiesAction->setText(i18n("Properties"));
-    d->mShowPropertiesAction->setIcon(KIcon("document-properties"));
+    d->mShowPropertiesAction->setIcon(QIcon::fromTheme("document-properties"));
 
     d->mCreateFolderAction = file->addAction("file_create_folder", this, SLOT(createFolder()));
     d->mCreateFolderAction->setText(i18n("Create Folder..."));
-    d->mCreateFolderAction->setIcon(KIcon("folder-new"));
+    d->mCreateFolderAction->setIcon(QIcon::fromTheme("folder-new"));
 
     d->mOpenWithAction = file->addAction("file_open_with");
     d->mOpenWithAction->setText(i18n("Open With"));
     QMenu* menu = new QMenu;
     d->mOpenWithAction->setMenu(menu);
-    connect(menu, SIGNAL(aboutToShow()),
-            SLOT(populateOpenMenu()));
-    connect(menu, SIGNAL(triggered(QAction*)),
-            SLOT(openWith(QAction*)));
+    connect(menu, &QMenu::aboutToShow, this, &FileOpsContextManagerItem::populateOpenMenu);
+    connect(menu, &QMenu::triggered, this, &FileOpsContextManagerItem::openWith);
 
     d->mRegularFileActionList
             << d->mRenameAction
@@ -268,7 +271,7 @@ void FileOpsContextManagerItem::updateActions()
     const bool urlIsValid = contextManager()->currentUrl().isValid();
     const bool dirUrlIsValid = contextManager()->currentDirUrl().isValid();
 
-    d->mInTrash = contextManager()->currentDirUrl().protocol() == "trash";
+    d->mInTrash = contextManager()->currentDirUrl().scheme() == "trash";
 
     d->mCutAction->setEnabled(selectionNotEmpty);
     d->mCopyAction->setEnabled(selectionNotEmpty);
@@ -293,9 +296,12 @@ void FileOpsContextManagerItem::updateActions()
 
 void FileOpsContextManagerItem::updatePasteAction()
 {
-    QPair<bool, QString> info = KonqOperations::pasteInfo(d->pasteTargetUrl());
-    d->mPasteAction->setEnabled(info.first);
-    d->mPasteAction->setText(info.second);
+    const QMimeData *mimeData = QApplication::clipboard()->mimeData();
+    bool enable;
+    KFileItem destItem(d->pasteTargetUrl());
+    const QString text = KIO::pasteActionText(mimeData, &enable, destItem);
+    d->mPasteAction->setEnabled(enable);
+    d->mPasteAction->setText(text);
 }
 
 void FileOpsContextManagerItem::updateSideBarContent()
@@ -319,7 +325,7 @@ void FileOpsContextManagerItem::showProperties()
     if (list.count() > 0) {
         KPropertiesDialog::showDialog(list, d->mGroup);
     } else {
-        KUrl url = contextManager()->currentDirUrl();
+        QUrl url = contextManager()->currentDirUrl();
         KPropertiesDialog::showDialog(url, d->mGroup);
     }
 }
@@ -327,21 +333,21 @@ void FileOpsContextManagerItem::showProperties()
 void FileOpsContextManagerItem::cut()
 {
     QMimeData* mimeData = d->selectionMimeData();
-    KonqMimeData::addIsCutSelection(mimeData, true);
+    KIO::setClipboardDataCut(mimeData, true);
     QApplication::clipboard()->setMimeData(mimeData);
 }
 
 void FileOpsContextManagerItem::copy()
 {
     QMimeData* mimeData = d->selectionMimeData();
-    KonqMimeData::addIsCutSelection(mimeData, false);
+    KIO::setClipboardDataCut(mimeData, false);
     QApplication::clipboard()->setMimeData(mimeData);
 }
 
 void FileOpsContextManagerItem::paste()
 {
-    const bool move = KonqMimeData::decodeIsCutSelection(QApplication::clipboard()->mimeData());
-    KIO::pasteClipboard(d->pasteTargetUrl(), d->mGroup, move);
+    KIO::Job *job = KIO::paste(QApplication::clipboard()->mimeData(), d->pasteTargetUrl());
+    KJobWidgets::setWindow(job, d->mGroup);
 }
 
 void FileOpsContextManagerItem::trash()
@@ -356,7 +362,9 @@ void FileOpsContextManagerItem::del()
 
 void FileOpsContextManagerItem::restore()
 {
-    KonqOperations::restoreTrashedItems(d->urlList(), d->mGroup);
+    KIO::RestoreJob *job = KIO::restoreFromTrash(d->urlList());
+    KJobWidgets::setWindow(job, d->mGroup);
+    job->uiDelegate()->setAutoErrorHandlingEnabled(true);
 }
 
 void FileOpsContextManagerItem::copyTo()
@@ -386,8 +394,10 @@ void FileOpsContextManagerItem::rename()
 
 void FileOpsContextManagerItem::createFolder()
 {
-    KUrl url = contextManager()->currentDirUrl();
-    KonqOperations::newDir(d->mGroup, url);
+    QUrl url = contextManager()->currentDirUrl();
+    d->mNewFileMenu->setParentWidget(d->mGroup);
+    d->mNewFileMenu->setPopupFiles(QList<QUrl>() << url);
+    d->mNewFileMenu->createDirectory();
 }
 
 void FileOpsContextManagerItem::populateOpenMenu()
@@ -401,7 +411,7 @@ void FileOpsContextManagerItem::populateOpenMenu()
     Q_FOREACH(const KService::Ptr & service, d->mServiceList) {
         QString text = service->name().replace('&', "&&");
         QAction* action = openMenu->addAction(text);
-        action->setIcon(KIcon(service->icon()));
+        action->setIcon(QIcon::fromTheme(service->icon()));
         action->setData(idx);
         ++idx;
     }
@@ -415,7 +425,7 @@ void FileOpsContextManagerItem::openWith(QAction* action)
 {
     Q_ASSERT(action);
     KService::Ptr service;
-    KUrl::List list = d->urlList();
+    QList<QUrl> list = d->urlList();
 
     bool ok;
     int idx = action->data().toInt(&ok);
