@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "filtercontroller.moc"
+#include "filtercontroller.h"
 
 #include <config-gwenview.h>
 
@@ -32,15 +32,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QPainterPath>
 #include <QTimer>
 #include <QToolButton>
+#include <QDebug>
+#include <QIcon>
 
 // KDE
 #include <KComboBox>
-#include <KDebug>
 #include <KFileItem>
-#include <KIcon>
 #include <KIconLoader>
-#include <KLineEdit>
-#include <KLocale>
+#include <QLineEdit>
+#include <KLocalizedString>
 
 // Local
 #include <lib/datewidget.h>
@@ -116,7 +116,7 @@ struct NameFilterWidgetPrivate
 {
     QPointer<NameFilter> mFilter;
     KComboBox* mModeComboBox;
-    KLineEdit* mLineEdit;
+    QLineEdit* mLineEdit;
 };
 
 NameFilterWidget::NameFilterWidget(SortedDirModel* model)
@@ -128,7 +128,7 @@ NameFilterWidget::NameFilterWidget(SortedDirModel* model)
     d->mModeComboBox->addItem(i18n("Name contains"), QVariant(NameFilter::Contains));
     d->mModeComboBox->addItem(i18n("Name does not contain"), QVariant(NameFilter::DoesNotContain));
 
-    d->mLineEdit = new KLineEdit;
+    d->mLineEdit = new QLineEdit;
 
     QHBoxLayout* layout = new QHBoxLayout(this);
     layout->setMargin(0);
@@ -467,7 +467,7 @@ void TagFilterWidget::updateTagSetFilter()
 {
     QModelIndex index = d->mTagComboBox->model()->index(d->mTagComboBox->currentIndex(), 0);
     if (!index.isValid()) {
-        kWarning() << "Invalid index";
+        qWarning() << "Invalid index";
         return;
     }
     SemanticInfoTag tag = index.data(TagModel::TagRole).toString();
@@ -494,7 +494,7 @@ public:
     void setFilterWidget(QWidget* widget)
     {
         QToolButton* closeButton = new QToolButton;
-        closeButton->setIcon(KIcon("window-close"));
+        closeButton->setIcon(QIcon::fromTheme("window-close"));
         closeButton->setAutoRaise(true);
         closeButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
         int size = IconSize(KIconLoader::Small);
