@@ -31,7 +31,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 class QStringList;
 
 class KActionCollection;
-class KUrl;
+class QUrl;
 
 namespace Gwenview
 {
@@ -61,7 +61,7 @@ public:
     void setFullScreenMode(bool);
 
 public Q_SLOTS:
-    void setCurrentUrl(const KUrl&);
+    void setCurrentUrl(const QUrl&);
 
 private Q_SLOTS:
     void updateCurrentUrlWidgets();
