@@ -19,16 +19,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
 // Self
-#include "imageopscontextmanageritem.moc"
+#include "imageopscontextmanageritem.h"
 
 // Qt
 #include <QApplication>
+#include <QAction>
+#include <QDebug>
 
 // KDE
-#include <KAction>
-#include <KDebug>
-#include <KInputDialog>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KActionCollection>
 #include <KActionCategory>
@@ -56,7 +55,7 @@ namespace Gwenview
 #undef LOG
 //#define ENABLE_LOG
 #ifdef ENABLE_LOG
-#define LOG(x) kDebug() << x
+#define LOG(x) qDebug() << x
 #else
 #define LOG(x) ;
 #endif
@@ -67,14 +66,14 @@ struct ImageOpsContextManagerItem::Private
     MainWindow* mMainWindow;
     SideBarGroup* mGroup;
 
-    KAction* mRotateLeftAction;
-    KAction* mRotateRightAction;
-    KAction* mMirrorAction;
-    KAction* mFlipAction;
-    KAction* mResizeAction;
-    KAction* mCropAction;
-    KAction* mRedEyeReductionAction;
-    QList<KAction*> mActionList;
+    QAction * mRotateLeftAction;
+    QAction * mRotateRightAction;
+    QAction * mMirrorAction;
+    QAction * mFlipAction;
+    QAction * mResizeAction;
+    QAction * mCropAction;
+    QAction * mRedEyeReductionAction;
+    QList<QAction *> mActionList;
 
     void setupActions()
     {
@@ -84,37 +83,37 @@ struct ImageOpsContextManagerItem::Private
         mRotateLeftAction->setPriority(QAction::LowPriority);
         mRotateLeftAction->setText(i18n("Rotate Left"));
         mRotateLeftAction->setToolTip(i18nc("@info:tooltip", "Rotate image to the left"));
-        mRotateLeftAction->setIcon(KIcon("object-rotate-left"));
-        mRotateLeftAction->setShortcut(Qt::CTRL + Qt::Key_L);
+        mRotateLeftAction->setIcon(QIcon::fromTheme("object-rotate-left"));
+        actionCollection->setDefaultShortcut(mRotateLeftAction, Qt::CTRL + Qt::Key_L);
 
         mRotateRightAction = edit->addAction("rotate_right", q, SLOT(rotateRight()));
         mRotateRightAction->setPriority(QAction::LowPriority);
         mRotateRightAction->setText(i18n("Rotate Right"));
         mRotateRightAction->setToolTip(i18nc("@info:tooltip", "Rotate image to the right"));
-        mRotateRightAction->setIcon(KIcon("object-rotate-right"));
-        mRotateRightAction->setShortcut(Qt::CTRL + Qt::Key_R);
+        mRotateRightAction->setIcon(QIcon::fromTheme("object-rotate-right"));
+        actionCollection->setDefaultShortcut(mRotateRightAction, Qt::CTRL + Qt::Key_R);
 
         mMirrorAction = edit->addAction("mirror", q, SLOT(mirror()));
         mMirrorAction->setText(i18n("Mirror"));
-        mMirrorAction->setIcon(KIcon("object-flip-horizontal"));
+        mMirrorAction->setIcon(QIcon::fromTheme("object-flip-horizontal"));
 
         mFlipAction = edit->addAction("flip", q, SLOT(flip()));
         mFlipAction->setText(i18n("Flip"));
-        mFlipAction->setIcon(KIcon("object-flip-vertical"));
+        mFlipAction->setIcon(QIcon::fromTheme("object-flip-vertical"));
 
         mResizeAction = edit->addAction("resize", q, SLOT(resizeImage()));
         mResizeAction->setText(i18n("Resize"));
-        mResizeAction->setIcon(KIcon("transform-scale"));
-        mResizeAction->setShortcut(Qt::SHIFT + Qt::Key_R);
+        mResizeAction->setIcon(QIcon::fromTheme("transform-scale"));
+        actionCollection->setDefaultShortcut(mResizeAction, Qt::SHIFT + Qt::Key_R);
 
         mCropAction = edit->addAction("crop", q, SLOT(crop()));
         mCropAction->setText(i18n("Crop"));
-        mCropAction->setIcon(KIcon("transform-crop-and-resize"));
-        mCropAction->setShortcut(Qt::SHIFT + Qt::Key_C);
+        mCropAction->setIcon(QIcon::fromTheme("transform-crop-and-resize"));
+        actionCollection->setDefaultShortcut(mCropAction, Qt::SHIFT + Qt::Key_C);
 
         mRedEyeReductionAction = edit->addAction("red_eye_reduction", q, SLOT(startRedEyeReduction()));
         mRedEyeReductionAction->setText(i18n("Red Eye Reduction"));
-        //mRedEyeReductionAction->setIcon(KIcon("transform-crop-and-resize"));
+        //mRedEyeReductionAction->setIcon(QIcon::fromTheme("transform-crop-and-resize"));
 
         mActionList
                 << mRotateLeftAction
@@ -129,7 +128,7 @@ struct ImageOpsContextManagerItem::Private
 
     bool ensureEditable()
     {
-        KUrl url = q->contextManager()->currentUrl();
+        QUrl url = q->contextManager()->currentUrl();
         Document::Ptr doc = DocumentFactory::instance()->load(url);
         doc->startLoadingFullImage();
         doc->waitUntilLoaded();
@@ -176,7 +175,7 @@ void ImageOpsContextManagerItem::updateSideBarContent()
     }
 
     d->mGroup->clear();
-    Q_FOREACH(KAction * action, d->mActionList) {
+    Q_FOREACH(QAction * action, d->mActionList) {
         if (action->isEnabled() && action->priority() != QAction::LowPriority) {
             d->mGroup->addAction(action);
         }
@@ -254,14 +253,12 @@ void ImageOpsContextManagerItem::crop()
     }
     RasterImageView* imageView = d->mMainWindow->viewMainPage()->imageView();
     if (!imageView) {
-        kError() << "No ImageView available!";
+        qCritical() << "No ImageView available!";
         return;
     }
     CropTool* tool = new CropTool(imageView);
-    connect(tool, SIGNAL(imageOperationRequested(AbstractImageOperation*)),
-            SLOT(applyImageOperation(AbstractImageOperation*)));
-    connect(tool, SIGNAL(done()),
-            SLOT(restoreDefaultImageViewTool()));
+    connect(tool, &CropTool::imageOperationRequested, this, &ImageOpsContextManagerItem::applyImageOperation);
+    connect(tool, &CropTool::done, this, &ImageOpsContextManagerItem::restoreDefaultImageViewTool);
 
     d->mMainWindow->setDistractionFreeMode(true);
     imageView->setCurrentTool(tool);
@@ -274,14 +271,12 @@ void ImageOpsContextManagerItem::startRedEyeReduction()
     }
     RasterImageView* view = d->mMainWindow->viewMainPage()->imageView();
     if (!view) {
-        kError() << "No RasterImageView available!";
+        qCritical() << "No RasterImageView available!";
         return;
     }
     RedEyeReductionTool* tool = new RedEyeReductionTool(view);
-    connect(tool, SIGNAL(imageOperationRequested(AbstractImageOperation*)),
-            SLOT(applyImageOperation(AbstractImageOperation*)));
-    connect(tool, SIGNAL(done()),
-            SLOT(restoreDefaultImageViewTool()));
+    connect(tool, &RedEyeReductionTool::imageOperationRequested, this, &ImageOpsContextManagerItem::applyImageOperation);
+    connect(tool, &RedEyeReductionTool::done, this, &ImageOpsContextManagerItem::restoreDefaultImageViewTool);
 
     d->mMainWindow->setDistractionFreeMode(true);
     view->setCurrentTool(tool);
@@ -290,7 +285,7 @@ void ImageOpsContextManagerItem::startRedEyeReduction()
 void ImageOpsContextManagerItem::applyImageOperation(AbstractImageOperation* op)
 {
     // For now, we only support operations on one image
-    KUrl url = contextManager()->currentUrl();
+    QUrl url = contextManager()->currentUrl();
 
     Document::Ptr doc = DocumentFactory::instance()->load(url);
     op->applyToDocument(doc);
@@ -300,7 +295,7 @@ void ImageOpsContextManagerItem::restoreDefaultImageViewTool()
 {
     RasterImageView* imageView = d->mMainWindow->viewMainPage()->imageView();
     if (!imageView) {
-        kError() << "No RasterImageView available!";
+        qCritical() << "No RasterImageView available!";
         return;
     }
 
