@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "kipiimagecollectionselector.moc"
+#include "kipiimagecollectionselector.h"
 
 // Qt
 #include <QListWidget>
@@ -58,8 +58,7 @@ KIPIImageCollectionSelector::KIPIImageCollectionSelector(KIPIInterface* interfac
         item->setData(Qt::UserRole, name);
     }
 
-    connect(d->mListWidget, SIGNAL(currentRowChanged(int)),
-            SIGNAL(selectionChanged()));
+    connect(d->mListWidget, &QListWidget::currentRowChanged, this, &KIPIImageCollectionSelector::selectionChanged);
 
     QVBoxLayout* layout = new QVBoxLayout(this);
     layout->addWidget(d->mListWidget);
