@@ -121,8 +121,8 @@ int main(int argc, char *argv[])
     KLocalizedString::setApplicationDomain("gwenview");
     QScopedPointer<KAboutData> aboutData(
         Gwenview::createAboutData(
-            QStringLiteral("gwenview"), /* component name */
-            i18n("Gwenview")            /* display name */
+            QStringLiteral("org.kde.gwenview"), /* component name */
+            i18n("Gwenview")                    /* display name */
         ));
     aboutData->setShortDescription(i18n("An Image Viewer"));
 
