@@ -28,7 +28,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 class QModelIndex;
 
-class KUrl;
+class QUrl;
 
 namespace Gwenview
 {
@@ -45,7 +45,7 @@ public:
     /**
      * Defines the url to display when the window is shown for the first time.
      */
-    void setInitialUrl(const KUrl&);
+    void setInitialUrl(const QUrl&);
 
     void startSlideShow();
 
@@ -61,30 +61,30 @@ public Q_SLOTS:
     /**
      * Go to url, without changing current mode
      */
-    void goToUrl(const KUrl&);
+    void goToUrl(const QUrl&);
 
 Q_SIGNALS:
     void viewModeChanged();
 
 public Q_SLOTS:
-    virtual void setCaption(const QString&);
+    virtual void setCaption(const QString&) Q_DECL_OVERRIDE;
 
-    virtual void setCaption(const QString&, bool modified);
+    virtual void setCaption(const QString&, bool modified) Q_DECL_OVERRIDE;
 
 protected:
-    virtual bool queryClose();
-    virtual QSize sizeHint() const;
-    virtual void showEvent(QShowEvent*);
-    virtual void resizeEvent(QResizeEvent*);
-    virtual void saveProperties(KConfigGroup&);
-    virtual void readProperties(const KConfigGroup&);
+    virtual bool queryClose() Q_DECL_OVERRIDE;
+    virtual QSize sizeHint() const Q_DECL_OVERRIDE;
+    virtual void showEvent(QShowEvent*) Q_DECL_OVERRIDE;
+    virtual void resizeEvent(QResizeEvent*) Q_DECL_OVERRIDE;
+    virtual void saveProperties(KConfigGroup&) Q_DECL_OVERRIDE;
+    virtual void readProperties(const KConfigGroup&) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void setActiveViewModeAction(QAction* action);
-    void openDirUrl(const KUrl&);
+    void openDirUrl(const QUrl&);
     void slotThumbnailViewIndexActivated(const QModelIndex&);
 
-    void slotStartMainPageUrlSelected(const KUrl&);
+    void slotStartMainPageUrlSelected(const QUrl&);
 
     void goUp();
     void toggleSideBar(bool visible);
@@ -95,7 +95,7 @@ private Q_SLOTS:
     void slotDirListerCompleted();
 
     void slotSelectionChanged();
-    void slotCurrentDirUrlChanged(const KUrl& url);
+    void slotCurrentDirUrlChanged(const QUrl &url);
 
     void goToPrevious();
     void goToNext();
@@ -111,10 +111,10 @@ private Q_SLOTS:
     void saveCurrent();
     void saveCurrentAs();
     void openFile();
-    void openUrl(const KUrl& url);
+    void openUrl(const QUrl& url);
     void reload();
 
-    void showDocumentInFullScreen(const KUrl&);
+    void showDocumentInFullScreen(const QUrl&);
 
     void showConfigDialog();
     void loadConfig();
