@@ -17,23 +17,21 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
-#include "viewmainpage.moc"
+#include "viewmainpage.h"
 
 // Qt
-#include <QApplication>
 #include <QCheckBox>
 #include <QItemSelectionModel>
-#include <QLabel>
 #include <QShortcut>
 #include <QToolButton>
 #include <QVBoxLayout>
+#include <QDebug>
+#include <QMenu>
 
 // KDE
 #include <KActionCollection>
 #include <KActionCategory>
-#include <KDebug>
-#include <KLocale>
-#include <KMenu>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KModelIndexProxyMapper>
 #include <KToggleAction>
@@ -58,6 +56,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <lib/statusbartoolbutton.h>
 #include <lib/thumbnailview/thumbnailbarview.h>
 #include <lib/zoomwidget.h>
+#include <lib/zoommode.h>
 
 namespace Gwenview
 {
@@ -66,7 +65,7 @@ namespace Gwenview
 #undef LOG
 //#define ENABLE_LOG
 #ifdef ENABLE_LOG
-#define LOG(x) kDebug() << x
+#define LOG(x) qDebug() << x
 #else
 #define LOG(x) ;
 #endif
@@ -163,6 +162,7 @@ struct ViewMainPagePrivate
     bool mFullScreenMode;
     bool mCompareMode;
     bool mThumbnailBarVisibleBeforeFullScreen;
+    ZoomMode::Enum mZoomMode;
 
     void setupThumbnailBar()
     {
@@ -246,28 +246,18 @@ struct ViewMainPagePrivate
 
         // Connect context menu
         // If you need to connect another view signal, make sure it is disconnected in deleteDocumentView
-        QObject::connect(view, SIGNAL(contextMenuRequested()),
-                         q, SLOT(showContextMenu()));
+        QObject::connect(view, &DocumentView::contextMenuRequested, q, &ViewMainPage::showContextMenu);
 
-        QObject::connect(view, SIGNAL(completed()),
-                         q, SIGNAL(completed()));
-        QObject::connect(view, SIGNAL(previousImageRequested()),
-                         q, SIGNAL(previousImageRequested()));
-        QObject::connect(view, SIGNAL(nextImageRequested()),
-                         q, SIGNAL(nextImageRequested()));
-        QObject::connect(view, SIGNAL(captionUpdateRequested(QString)),
-                         q, SIGNAL(captionUpdateRequested(QString)));
-        QObject::connect(view, SIGNAL(toggleFullScreenRequested()),
-                         q, SIGNAL(toggleFullScreenRequested()));
-        QObject::connect(view, SIGNAL(focused(DocumentView*)),
-                         q, SLOT(slotViewFocused(DocumentView*)));
-        QObject::connect(view, SIGNAL(hudTrashClicked(DocumentView*)),
-                         q, SLOT(trashView(DocumentView*)));
-        QObject::connect(view, SIGNAL(hudDeselectClicked(DocumentView*)),
-                         q, SLOT(deselectView(DocumentView*)));
+        QObject::connect(view, &DocumentView::completed, q, &ViewMainPage::completed);
+        QObject::connect(view, &DocumentView::previousImageRequested, q, &ViewMainPage::previousImageRequested);
+        QObject::connect(view, &DocumentView::nextImageRequested, q, &ViewMainPage::nextImageRequested);
+        QObject::connect(view, &DocumentView::captionUpdateRequested, q, &ViewMainPage::captionUpdateRequested);
+        QObject::connect(view, &DocumentView::toggleFullScreenRequested, q, &ViewMainPage::toggleFullScreenRequested);
+        QObject::connect(view, &DocumentView::focused, q, &ViewMainPage::slotViewFocused);
+        QObject::connect(view, &DocumentView::hudTrashClicked, q, &ViewMainPage::trashView);
+        QObject::connect(view, &DocumentView::hudDeselectClicked, q, &ViewMainPage::deselectView);
 
-        QObject::connect(view, SIGNAL(videoFinished()),
-                         mSlideShow, SLOT(resumeAndGoToNextUrl()));
+        QObject::connect(view, &DocumentView::videoFinished, mSlideShow, &SlideShow::resumeAndGoToNextUrl);
 
         mDocumentViews << view;
         mActivityResources.insert(view, new KActivities::ResourceInstance(q->window()->winId(), view));
@@ -375,9 +365,9 @@ struct ViewMainPagePrivate
 
     QModelIndex indexForView(DocumentView* view) const
     {
-        KUrl url = view->url();
+        QUrl url = view->url();
         if (!url.isValid()) {
-            kWarning() << "View does not display any document!";
+            qWarning() << "View does not display any document!";
             return QModelIndex();
         }
 
@@ -415,7 +405,7 @@ ViewMainPage::ViewMainPage(QWidget* parent, SlideShow* slideShow, KActionCollect
 
     QShortcut* goToBrowseModeShortcut = new QShortcut(this);
     goToBrowseModeShortcut->setKey(Qt::Key_Return);
-    connect(goToBrowseModeShortcut, SIGNAL(activated()), SIGNAL(goToBrowseModeRequested()));
+    connect(goToBrowseModeShortcut, &QShortcut::activated, this, &ViewMainPage::goToBrowseModeRequested);
 
     d->setupToolContainer();
     d->setupStatusBar();
@@ -432,16 +422,15 @@ ViewMainPage::ViewMainPage(QWidget* parent, SlideShow* slideShow, KActionCollect
 
     d->mToggleThumbnailBarAction = view->add<KToggleAction>(QString("toggle_thumbnailbar"));
     d->mToggleThumbnailBarAction->setText(i18n("Thumbnail Bar"));
-    d->mToggleThumbnailBarAction->setIcon(KIcon("folder-image"));
-    d->mToggleThumbnailBarAction->setShortcut(Qt::CTRL | Qt::Key_B);
+    d->mToggleThumbnailBarAction->setIcon(QIcon::fromTheme("folder-image"));
+    actionCollection->setDefaultShortcut(d->mToggleThumbnailBarAction, Qt::CTRL + Qt::Key_B);
     d->mToggleThumbnailBarAction->setChecked(GwenviewConfig::thumbnailBarIsVisible());
-    connect(d->mToggleThumbnailBarAction, SIGNAL(triggered(bool)),
-            this, SLOT(setThumbnailBarVisibility(bool)));
+    connect(d->mToggleThumbnailBarAction, &KToggleAction::triggered, this, &ViewMainPage::setThumbnailBarVisibility);
     d->mToggleThumbnailBarButton->setDefaultAction(d->mToggleThumbnailBarAction);
 
     d->mSynchronizeAction = view->add<KToggleAction>("synchronize_views");
     d->mSynchronizeAction->setText(i18n("Synchronize"));
-    d->mSynchronizeAction->setShortcut(Qt::CTRL | Qt::Key_Y);
+    actionCollection->setDefaultShortcut(d->mSynchronizeAction, Qt::CTRL + Qt::Key_Y);
     connect(d->mSynchronizeAction, SIGNAL(toggled(bool)),
             d->mSynchronizer, SLOT(setActive(bool)));
     // Ensure mSynchronizeAction and mSynchronizeCheckBox are in sync
@@ -489,20 +478,13 @@ void ViewMainPage::loadConfig()
         d->mThumbnailBar->setUpdatesEnabled(true);
     }
 
-    if (GwenviewConfig::showLockZoomButton()) {
-        d->mZoomWidget->setZoomLocked(GwenviewConfig::lockZoom());
-    } else {
-        d->mZoomWidget->setLockZoomButtonVisible(false);
-    }
+    d->mZoomMode = GwenviewConfig::zoomMode();
 }
 
 void ViewMainPage::saveConfig()
 {
     d->saveSplitterConfig();
     GwenviewConfig::setThumbnailBarIsVisible(d->mToggleThumbnailBarAction->isChecked());
-    if (GwenviewConfig::showLockZoomButton()) {
-        GwenviewConfig::setLockZoom(d->mZoomWidget->isZoomLocked());
-    }
 }
 
 void ViewMainPage::setThumbnailBarVisibility(bool visible)
@@ -545,7 +527,7 @@ ThumbnailBarView* ViewMainPage::thumbnailBar() const
     return d->mThumbnailBar;
 }
 
-inline void addActionToMenu(KMenu* menu, KActionCollection* actionCollection, const char* name)
+inline void addActionToMenu(QMenu* menu, KActionCollection* actionCollection, const char* name)
 {
     QAction* action = actionCollection->action(name);
     if (action) {
@@ -555,7 +537,7 @@ inline void addActionToMenu(KMenu* menu, KActionCollection* actionCollection, co
 
 void ViewMainPage::showContextMenu()
 {
-    KMenu menu(this);
+    QMenu menu(this);
     addActionToMenu(&menu, d->mActionCollection, "fullscreen");
     menu.addSeparator();
     addActionToMenu(&menu, d->mActionCollection, "go_previous");
@@ -586,9 +568,9 @@ QSize ViewMainPage::sizeHint() const
     return QSize(400, 300);
 }
 
-KUrl ViewMainPage::url() const
+QUrl ViewMainPage::url() const
 {
-    GV_RETURN_VALUE_IF_FAIL(d->currentView(), KUrl());
+    GV_RETURN_VALUE_IF_FAIL(d->currentView(), QUrl());
     return d->currentView()->url();
 }
 
@@ -620,34 +602,34 @@ DocumentView* ViewMainPage::documentView() const
     return d->currentView();
 }
 
-void ViewMainPage::openUrl(const KUrl& url)
+void ViewMainPage::openUrl(const QUrl &url)
 {
-    openUrls(KUrl::List() << url, url);
+    openUrls(QList<QUrl>() << url, url);
 }
 
-void ViewMainPage::openUrls(const KUrl::List& allUrls, const KUrl& currentUrl)
+void ViewMainPage::openUrls(const QList<QUrl>& allUrls, const QUrl &currentUrl)
 {
     DocumentView::Setup setup;
 
-    QSet<KUrl> urls = allUrls.toSet();
+    QSet<QUrl> urls = allUrls.toSet();
     d->mCompareMode = urls.count() > 1;
 
-    typedef QMap<KUrl, DocumentView*> ViewForUrlMap;
+    typedef QMap<QUrl, DocumentView*> ViewForUrlMap;
     ViewForUrlMap viewForUrlMap;
 
     if (!d->mDocumentViews.isEmpty()) {
         d->mDocumentViewContainer->updateSetup(d->mDocumentViews.last());
     }
-    if (!d->mDocumentViews.isEmpty() && d->mZoomWidget->isZoomLocked()) {
-        setup = d->mDocumentViews.last()->setup();
-    } else {
+    if (d->mDocumentViews.isEmpty() || d->mZoomMode == ZoomMode::Autofit) {
         setup.valid = true;
         setup.zoomToFit = true;
+    } else {
+        setup = d->mDocumentViews.last()->setup();
     }
     // Destroy views which show urls we don't care about, remove from "urls" the
     // urls which already have a view.
     Q_FOREACH(DocumentView * view, d->mDocumentViews) {
-        KUrl url = view->url();
+        QUrl url = view->url();
         if (urls.contains(url)) {
             // view displays an url we must display, keep it
             urls.remove(url);
@@ -659,9 +641,9 @@ void ViewMainPage::openUrls(const KUrl::List& allUrls, const KUrl& currentUrl)
     }
 
     // Create view for remaining urls
-    Q_FOREACH(const KUrl & url, urls) {
+    Q_FOREACH(const QUrl &url, urls) {
         if (d->mDocumentViews.count() >= MaxViewCount) {
-            kWarning() << "Too many documents to show";
+            qWarning() << "Too many documents to show";
             break;
         }
         DocumentView* view = d->createDocumentView();
@@ -670,7 +652,7 @@ void ViewMainPage::openUrls(const KUrl::List& allUrls, const KUrl& currentUrl)
 
     // Set sortKey to match url order
     int sortKey = 0;
-    Q_FOREACH(const KUrl& url, allUrls) {
+    Q_FOREACH(const QUrl &url, allUrls) {
         viewForUrlMap[url]->setSortKey(sortKey);
         ++sortKey;
     }
@@ -684,10 +666,10 @@ void ViewMainPage::openUrls(const KUrl::List& allUrls, const KUrl& currentUrl)
         it = viewForUrlMap.constBegin(),
         end = viewForUrlMap.constEnd();
     for (; it != end; ++it) {
-        KUrl url = it.key();
+        QUrl url = it.key();
         DocumentView* view = it.value();
         DocumentView::Setup savedSetup = d->mDocumentViewContainer->savedSetup(url);
-        view->openUrl(url, savedSetup.valid ? savedSetup : setup);
+        view->openUrl(url, d->mZoomMode == ZoomMode::Individual && savedSetup.valid ? savedSetup : setup);
         d->mActivityResources.value(view)->setUri(url);
     }
 
@@ -717,7 +699,7 @@ void ViewMainPage::reload()
     }
     Document::Ptr doc = view->document();
     if (!doc) {
-        kWarning() << "!doc";
+        qWarning() << "!doc";
         return;
     }
     if (doc->isModified()) {
@@ -751,9 +733,9 @@ void ViewMainPage::slotViewFocused(DocumentView* view)
 
 void ViewMainPage::trashView(DocumentView* view)
 {
-    KUrl url = view->url();
+    QUrl url = view->url();
     deselectView(view);
-    FileOperations::trash(KUrl::List() << url, this);
+    FileOperations::trash(QList<QUrl>() << url, this);
 }
 
 void ViewMainPage::deselectView(DocumentView* view)
