@@ -19,17 +19,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "datewidget.moc"
+#include "datewidget.h"
 
 // Qt
 #include <QDate>
 #include <QHBoxLayout>
+#include <QLocale>
 
 // KDE
 #include <KDatePicker>
-#include <KDebug>
 #include <KIconLoader>
-#include <KLocale>
 
 // Local
 #include <lib/statusbartoolbutton.h>
@@ -56,15 +55,13 @@ struct DateWidgetPrivate
         mDatePicker->hide();
         mDatePicker->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
 
-        QObject::connect(mDatePicker, SIGNAL(dateEntered(QDate)),
-                         q, SLOT(slotDatePickerModified(QDate)));
-        QObject::connect(mDatePicker, SIGNAL(dateSelected(QDate)),
-                         q, SLOT(slotDatePickerModified(QDate)));
+        QObject::connect(mDatePicker, &KDatePicker::dateEntered, q, &DateWidget::slotDatePickerModified);
+        QObject::connect(mDatePicker, &KDatePicker::dateSelected, q, &DateWidget::slotDatePickerModified);
     }
 
     void updateButton()
     {
-        mDateButton->setText(KGlobal::locale()->formatDate(mDate, KLocale::ShortDate));
+        mDateButton->setText(QLocale().toString(mDate, QLocale::ShortFormat));
     }
 
     void adjustDate(int delta)
@@ -87,16 +84,16 @@ DateWidget::DateWidget(QWidget* parent)
     d->mPreviousButton->setGroupPosition(StatusBarToolButton::GroupLeft);
     // FIXME: RTL
     d->mPreviousButton->setIcon(SmallIcon("go-previous"));
-    connect(d->mPreviousButton, SIGNAL(clicked()), SLOT(goToPrevious()));
+    connect(d->mPreviousButton, &StatusBarToolButton::clicked, this, &DateWidget::goToPrevious);
 
     d->mDateButton = new StatusBarToolButton;
     d->mDateButton->setGroupPosition(StatusBarToolButton::GroupCenter);
-    connect(d->mDateButton, SIGNAL(clicked()), SLOT(showDatePicker()));
+    connect(d->mDateButton, &StatusBarToolButton::clicked, this, &DateWidget::showDatePicker);
 
     d->mNextButton = new StatusBarToolButton;
     d->mNextButton->setGroupPosition(StatusBarToolButton::GroupRight);
     d->mNextButton->setIcon(SmallIcon("go-next"));
-    connect(d->mNextButton, SIGNAL(clicked()), SLOT(goToNext()));
+    connect(d->mNextButton, &StatusBarToolButton::clicked, this, &DateWidget::goToNext);
 
     QHBoxLayout* layout = new QHBoxLayout(this);
     layout->setMargin(0);
