@@ -44,7 +44,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <KProtocolInfo>
 
 #ifdef KDCRAW_FOUND
-#include <libkdcraw/kdcraw.h>
+#include <kdcraw/kdcraw.h>
 #endif
 
 // Local
