@@ -35,7 +35,7 @@ class LoadingJob : public DocumentJob
 {
     Q_OBJECT
 protected:
-    void doStart();
+    void doStart() Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void slotLoaded();
