@@ -19,22 +19,21 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "birdeyeview.moc"
+#include "birdeyeview.h"
 
 // Local
 #include <lib/document/document.h>
 #include <lib/documentview/documentview.h>
 
 // KDE
-#include <KDebug>
 
 // Qt
 #include <QApplication>
-#include <QCursor>
 #include <QGraphicsSceneEvent>
 #include <QPainter>
 #include <QPropertyAnimation>
 #include <QTimer>
+#include <QDebug>
 
 namespace Gwenview
 {
@@ -116,7 +115,7 @@ BirdEyeView::BirdEyeView(DocumentView* docView)
     d->mAutoHideTimer = new QTimer(this);
     d->mAutoHideTimer->setSingleShot(true);
     d->mAutoHideTimer->setInterval(AUTOHIDE_DELAY);
-    connect(d->mAutoHideTimer, SIGNAL(timeout()), SLOT(slotAutoHideTimeout()));
+    connect(d->mAutoHideTimer, &QTimer::timeout, this, &BirdEyeView::slotAutoHideTimeout);
 
     // Hide ourself by default, to avoid startup flashes (if we let updateOpacity
     // update opacity, it will do so through an animation)
