@@ -124,8 +124,7 @@ private:
         : mUrl(url)
         , mDateTime(dateTime)
         , mConfigPath(configPath) {
-        QUrl urlForView = mUrl;
-        setText(urlForView.toDisplayString());
+        setText(mUrl.toDisplayString());
 
         QMimeDatabase db;
         const QString iconName = db.mimeTypeForUrl(mUrl).iconName();
