@@ -19,12 +19,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "placetreemodel.moc"
+#include "placetreemodel.h"
 
 // Qt
+#include <QUrl>
 
 // KDE
-#include <KDebug>
 #include <KDirLister>
 #include <KFilePlacesModel>
 
@@ -37,12 +37,12 @@ namespace Gwenview
 /**
  * Here is how the mapping work:
  *
- * Place1     Node(dirModel1, KUrl())
+ * Place1     Node(dirModel1, QUrl())
  *   Photos   Node(dirModel1, place1Url)
  *     2008   Node(dirModel1, place1Url/Photos)
  *     2009   Node(dirModel1, place1Url/Photos)
  *
- * Place2     Node(dirModel2, KUrl())
+ * Place2     Node(dirModel2, QUrl())
  * ...
  * Node contains the parent url, not the url of the node itself, because
  * for some unknown reason when accessing rows from a slot connected to
@@ -61,13 +61,13 @@ struct Node
         : model(0)
     {}
 
-    Node(SortedDirModel* _model, const KUrl& _parentUrl)
+    Node(SortedDirModel* _model, const QUrl &_parentUrl)
         : model(_model)
         , parentUrl(_parentUrl)
     {}
 
     SortedDirModel* model;
-    KUrl parentUrl;
+    QUrl parentUrl;
 
     bool isPlace() const
     {
@@ -75,7 +75,7 @@ struct Node
     }
 };
 
-typedef QHash<KUrl, Node*> NodeHash;
+typedef QHash<QUrl, Node*> NodeHash;
 typedef QMap<SortedDirModel*, NodeHash*> NodeHashMap;
 
 struct PlaceTreeModelPrivate
@@ -92,7 +92,7 @@ struct PlaceTreeModelPrivate
         return *static_cast<Node*>(index.internalPointer());
     }
 
-    Node* createNode(SortedDirModel* dirModel, const KUrl& parentUrl) const
+    Node* createNode(SortedDirModel* dirModel, const QUrl &parentUrl) const
     {
         NodeHashMap::iterator nhmIt = mNodes.find(dirModel);
         if (nhmIt == mNodes.end()) {
@@ -107,11 +107,11 @@ struct PlaceTreeModelPrivate
         return nhIt.value();
     }
 
-    QModelIndex createIndexForDir(SortedDirModel* dirModel, const KUrl& url) const
+    QModelIndex createIndexForDir(SortedDirModel* dirModel, const QUrl &url) const
     {
         QModelIndex dirIndex = dirModel->indexForUrl(url);
         QModelIndex parentDirIndex = dirIndex.parent();
-        KUrl parentUrl;
+        QUrl parentUrl;
         if (parentDirIndex.isValid()) {
             parentUrl = dirModel->urlForIndex(parentDirIndex);
         } else {
@@ -120,7 +120,7 @@ struct PlaceTreeModelPrivate
         return createIndexForDirChild(dirModel, parentUrl, dirIndex.row(), dirIndex.column());
     }
 
-    QModelIndex createIndexForDirChild(SortedDirModel* dirModel, const KUrl& parentUrl, int row, int column) const
+    QModelIndex createIndexForDirChild(SortedDirModel* dirModel, const QUrl &parentUrl, int row, int column) const
     {
         Q_ASSERT(parentUrl.isValid());
         Node* node = createNode(dirModel, parentUrl);
@@ -131,7 +131,7 @@ struct PlaceTreeModelPrivate
     {
         int row = mDirModels.indexOf(dirModel);
         Q_ASSERT(row != -1);
-        Node* node = createNode(dirModel, KUrl());
+        Node* node = createNode(dirModel, QUrl());
         return q->createIndex(row, 0, node);
     }
 
@@ -153,10 +153,8 @@ PlaceTreeModel::PlaceTreeModel(QObject* parent)
     d->q = this;
 
     d->mPlacesModel = new KFilePlacesModel(this);
-    connect(d->mPlacesModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-            SLOT(slotPlacesRowsInserted(QModelIndex,int,int)));
-    connect(d->mPlacesModel, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-            SLOT(slotPlacesRowsAboutToBeRemoved(QModelIndex,int,int)));
+    connect(d->mPlacesModel, &KFilePlacesModel::rowsInserted, this, &PlaceTreeModel::slotPlacesRowsInserted);
+    connect(d->mPlacesModel, &KFilePlacesModel::rowsAboutToBeRemoved, this, &PlaceTreeModel::slotPlacesRowsAboutToBeRemoved);
 
     // Bootstrap
     slotPlacesRowsInserted(QModelIndex(), 0, d->mPlacesModel->rowCount() - 1);
@@ -212,7 +210,7 @@ QModelIndex PlaceTreeModel::index(int row, int column, const QModelIndex& parent
     QModelIndex parentDirIndex = d->dirIndexForNode(parentNode, parent);
 
     SortedDirModel* dirModel = parentNode.model;
-    KUrl parentUrl = dirModel->urlForIndex(parentDirIndex);
+    QUrl parentUrl = dirModel->urlForIndex(parentDirIndex);
     if (!parentUrl.isValid()) {
         // parent is a place
         parentUrl = dirModel->dirLister()->url();
@@ -288,7 +286,7 @@ void PlaceTreeModel::fetchMore(const QModelIndex& parent)
     const Node node = d->nodeForIndex(parent);
     if (!node.model->dirLister()->url().isValid()) {
         QModelIndex placeIndex = d->mPlacesModel->index(parent.row(), parent.column());
-        KUrl url = d->mPlacesModel->url(placeIndex);
+        QUrl url = d->mPlacesModel->url(placeIndex);
         node.model->dirLister()->openUrl(url, KDirLister::Keep);
         return;
     }
@@ -301,14 +299,10 @@ void PlaceTreeModel::slotPlacesRowsInserted(const QModelIndex& /*parent*/, int s
     beginInsertRows(QModelIndex(), start, end);
     for (int row = start; row <= end; ++row) {
         SortedDirModel* dirModel = new SortedDirModel(this);
-        connect(dirModel, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
-                SLOT(slotDirRowsAboutToBeInserted(QModelIndex,int,int)));
-        connect(dirModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-                SLOT(slotDirRowsInserted(QModelIndex,int,int)));
-        connect(dirModel, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-                SLOT(slotDirRowsAboutToBeRemoved(QModelIndex,int,int)));
-        connect(dirModel, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-                SLOT(slotDirRowsRemoved(QModelIndex,int,int)));
+        connect(dirModel, &SortedDirModel::rowsAboutToBeInserted, this, &PlaceTreeModel::slotDirRowsAboutToBeInserted);
+        connect(dirModel, &SortedDirModel::rowsInserted, this, &PlaceTreeModel::slotDirRowsInserted);
+        connect(dirModel, &SortedDirModel::rowsAboutToBeRemoved, this, &PlaceTreeModel::slotDirRowsAboutToBeRemoved);
+        connect(dirModel, &SortedDirModel::rowsAboutToBeRemoved, this, &PlaceTreeModel::slotDirRowsRemoved);
 
         d->mDirModels.insert(row, dirModel);
         KDirLister* lister = dirModel->dirLister();
@@ -333,7 +327,7 @@ void PlaceTreeModel::slotDirRowsAboutToBeInserted(const QModelIndex& parentDirIn
     SortedDirModel* dirModel = static_cast<SortedDirModel*>(sender());
     QModelIndex parentIndex;
     if (parentDirIndex.isValid()) {
-        KUrl url = dirModel->urlForIndex(parentDirIndex);
+        QUrl url = dirModel->urlForIndex(parentDirIndex);
         parentIndex = d->createIndexForDir(dirModel, url);
     } else {
         parentIndex = d->createIndexForPlace(dirModel);
@@ -351,7 +345,7 @@ void PlaceTreeModel::slotDirRowsAboutToBeRemoved(const QModelIndex& parentDirInd
     SortedDirModel* dirModel = static_cast<SortedDirModel*>(sender());
     QModelIndex parentIndex;
     if (parentDirIndex.isValid()) {
-        KUrl url = dirModel->urlForIndex(parentDirIndex);
+        QUrl url = dirModel->urlForIndex(parentDirIndex);
         parentIndex = d->createIndexForDir(dirModel, url);
     } else {
         parentIndex = d->createIndexForPlace(dirModel);
@@ -364,7 +358,7 @@ void PlaceTreeModel::slotDirRowsRemoved(const QModelIndex&, int, int)
     endRemoveRows();
 }
 
-KUrl PlaceTreeModel::urlForIndex(const QModelIndex& index) const
+QUrl PlaceTreeModel::urlForIndex(const QModelIndex& index) const
 {
     const Node node = d->nodeForIndex(index);
     if (node.isPlace()) {
