@@ -19,17 +19,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
 // Self
-#include "redeyereductiontool.moc"
+#include "redeyereductiontool.h"
 
 // Qt
 #include <QGraphicsSceneMouseEvent>
 #include <QPainter>
 #include <QPushButton>
 #include <QRect>
+#include <QDebug>
 
 // KDE
-#include <KDebug>
-#include <KLocale>
 
 // Local
 #include <lib/documentview/rasterimageview.h>
@@ -168,7 +167,7 @@ void RedEyeReductionTool::slotApplyClicked()
 {
     QRectF docRectF = d->rectF();
     if (!docRectF.isValid()) {
-        kWarning() << "invalid rect";
+        qWarning() << "invalid rect";
         return;
     }
     RedEyeReductionImageOperation* op = new RedEyeReductionImageOperation(docRectF);
