@@ -21,7 +21,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
-#include "thumbnailprovider.moc"
+#include "thumbnailprovider.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -32,17 +32,19 @@
 #include <QFile>
 #include <QImage>
 #include <QPixmap>
+#include <QCryptographicHash>
+#include <QDebug>
+#include <QTemporaryFile>
+#include <QApplication>
+#include <QStandardPaths>
 
 // KDE
-#include <KApplication>
-#include <KCodecs>
-#include <KDebug>
 #include <kde_file.h>
-#include <KFileItem>
 #include <KIO/JobUiDelegate>
 #include <KIO/PreviewJob>
 #include <KStandardDirs>
-#include <KTemporaryFile>
+#include <KJobWidgets>
+#include <KFileMetaInfo>
 
 // Local
 #include "mimetypeutils.h"
@@ -57,26 +59,25 @@ namespace Gwenview
 #undef LOG
 //#define ENABLE_LOG
 #ifdef ENABLE_LOG
-#define LOG(x) kDebug() << x
+#define LOG(x) qDebug() << x
 #else
 #define LOG(x) ;
 #endif
 
-K_GLOBAL_STATIC(ThumbnailWriter, sThumbnailWriter)
+Q_GLOBAL_STATIC(ThumbnailWriter, sThumbnailWriter)
 
-static QString generateOriginalUri(const KUrl& url_)
+static QString generateOriginalUri(const QUrl &url_)
 {
-    KUrl url = url_;
-    // Don't include the password if any
-    url.setPass(QString::null); //krazy:exclude=nullstrassign for old broken gcc
-    return url.url();
+    QUrl url = url_;
+    return url.adjusted(QUrl::RemovePassword).url();
 }
 
 static QString generateThumbnailPath(const QString& uri, ThumbnailGroup::Enum group)
 {
-    KMD5 md5(QFile::encodeName(uri));
     QString baseDir = ThumbnailProvider::thumbnailBaseDir(group);
-    return baseDir + QString(QFile::encodeName(md5.hexDigest())) + ".png";
+    QCryptographicHash md5(QCryptographicHash::Md5);
+    md5.addData(QFile::encodeName(uri));
+    return baseDir + QFile::encodeName(md5.result().toHex()) + ".png";
 }
 
 //------------------------------------------------------------------------
@@ -90,9 +91,9 @@ QString ThumbnailProvider::thumbnailBaseDir()
     if (sThumbnailBaseDir.isEmpty()) {
         const QByteArray customDir = qgetenv("GV_THUMBNAIL_DIR");
         if (customDir.isEmpty()) {
-            sThumbnailBaseDir = QDir::homePath() + "/.thumbnails/";
+            sThumbnailBaseDir = QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + QStringLiteral("/thumbnails/");
         } else {
-            sThumbnailBaseDir = QString::fromLocal8Bit(customDir.constData()) + '/';
+            sThumbnailBaseDir = QFile::decodeName(customDir) + '/';
         }
     }
     return sThumbnailBaseDir;
@@ -117,7 +118,7 @@ QString ThumbnailProvider::thumbnailBaseDir(ThumbnailGroup::Enum group)
     return dir;
 }
 
-void ThumbnailProvider::deleteImageThumbnail(const KUrl& url)
+void ThumbnailProvider::deleteImageThumbnail(const QUrl &url)
 {
     QString uri = generateOriginalUri(url);
     QFile::remove(generateThumbnailPath(uri, ThumbnailGroup::Normal));
@@ -132,12 +133,12 @@ static void moveThumbnailHelper(const QString& oldUri, const QString& newUri, Th
     if (!thumb.load(oldPath)) {
         return;
     }
-    thumb.setText("Thumb::URI", 0, newUri);
+    thumb.setText("Thumb::URI", newUri);
     thumb.save(newPath, "png");
     QFile::remove(QFile::encodeName(oldPath));
 }
 
-void ThumbnailProvider::moveThumbnail(const KUrl& oldUrl, const KUrl& newUrl)
+void ThumbnailProvider::moveThumbnail(const QUrl &oldUrl, const QUrl& newUrl)
 {
     QString oldUri = generateOriginalUri(oldUrl);
     QString newUri = generateOriginalUri(newUrl);
@@ -305,8 +306,7 @@ void ThumbnailProvider::determineNextIcon()
 
     // First, stat the orig file
     mState = STATE_STATORIG;
-    mCurrentUrl = mCurrentItem.url();
-    mCurrentUrl.cleanPath();
+    mCurrentUrl = mCurrentItem.url().adjusted(QUrl::NormalizePathSegments);
     mOriginalFileSize = mCurrentItem.size();
 
     // Do direct stat instead of using KIO if the file is local (faster)
@@ -321,7 +321,7 @@ void ThumbnailProvider::determineNextIcon()
     }
     if (!directStatOk) {
         KIO::Job* job = KIO::stat(mCurrentUrl, KIO::HideProgressInfo);
-        job->ui()->setWindow(KApplication::kApplication()->activeWindow());
+        KJobWidgets::setWindow(job, qApp->activeWindow());
         LOG("KIO::stat orig" << mCurrentUrl.url());
         addSubjob(job);
     }
@@ -427,7 +427,7 @@ void ThumbnailProvider::checkThumbnail()
 
     // If we are in the thumbnail dir, just load the file
     if (mCurrentUrl.isLocalFile()
-            && mCurrentUrl.directory().startsWith(thumbnailBaseDir())) {
+            && mCurrentUrl.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash).path().startsWith(thumbnailBaseDir())) {
         QImage image(mCurrentUrl.toLocalFile());
         emitThumbnailLoaded(image, image.size());
         determineNextIcon();
@@ -454,7 +454,7 @@ void ThumbnailProvider::checkThumbnail()
             if (ok) {
                 size = QSize(width, height);
             } else {
-                kWarning() << "Thumbnail for" << mOriginalUri << "does not contain correct image size information";
+                qWarning() << "Thumbnail for" << mOriginalUri << "does not contain correct image size information";
                 // Don't try to determine the size of a video, it probably won't work and
                 // will cause high I/O usage with big files (bug #307007).
                 if (MimeTypeUtils::urlKind(mCurrentUrl) == MimeTypeUtils::KIND_VIDEO) {
@@ -468,10 +468,10 @@ void ThumbnailProvider::checkThumbnail()
                     if (item.isValid()) {
                         size = item.value().toSize();
                     } else {
-                        kWarning() << "KFileMetaInfoItem for" << mOriginalUri << "did not get image size information";
+                        qWarning() << "KFileMetaInfoItem for" << mOriginalUri << "did not get image size information";
                     }
                 } else {
-                    kWarning() << "Could not get a valid KFileMetaInfo instance for" << mOriginalUri;
+                    qWarning() << "Could not get a valid KFileMetaInfo instance for" << mOriginalUri;
                 }
             }
             emitThumbnailLoaded(thumb, size);
@@ -489,21 +489,20 @@ void ThumbnailProvider::checkThumbnail()
             // Original is remote, download it
             mState = STATE_DOWNLOADORIG;
 
-            KTemporaryFile tempFile;
+            QTemporaryFile tempFile;
             tempFile.setAutoRemove(false);
             if (!tempFile.open()) {
-                kWarning() << "Couldn't create temp file to download " << mCurrentUrl.prettyUrl();
+                qWarning() << "Couldn't create temp file to download " << mCurrentUrl.toDisplayString();
                 emitThumbnailLoadingFailed();
                 determineNextIcon();
                 return;
             }
             mTempPath = tempFile.fileName();
 
-            KUrl url;
-            url.setPath(mTempPath);
+            QUrl url = QUrl::fromLocalFile(mTempPath);
             KIO::Job* job = KIO::file_copy(mCurrentUrl, url, -1, KIO::Overwrite | KIO::HideProgressInfo);
-            job->ui()->setWindow(KApplication::kApplication()->activeWindow());
-            LOG("Download remote file" << mCurrentUrl.prettyUrl() << "to" << url.pathOrUrl());
+            KJobWidgets::setWindow(job, qApp->activeWindow());
+            LOG("Download remote file" << mCurrentUrl.toDisplayString() << "to" << url.toDisplayString());
             addSubjob(job);
         }
     } else {
@@ -517,7 +516,7 @@ void ThumbnailProvider::checkThumbnail()
             mPreviewPlugins = KIO::PreviewJob::availablePlugins();
         }
         KIO::Job* job = KIO::filePreview(list, QSize(pixelSize, pixelSize), &mPreviewPlugins);
-        //job->ui()->setWindow(KApplication::kApplication()->activeWindow());
+        //KJobWidgets::setWindow(job, qApp->activeWindow());
         connect(job, SIGNAL(gotPreview(KFileItem,QPixmap)),
                 this, SLOT(slotGotPreview(KFileItem,QPixmap)));
         connect(job, SIGNAL(failed(KFileItem)),
