@@ -20,7 +20,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "thumbnailbarview.moc"
+#include "thumbnailbarview.h"
 
 // Qt
 #include <QApplication>
@@ -30,10 +30,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QPainter>
 #include <QTimeLine>
 #include <QToolTip>
+#include <QDebug>
+
+#ifdef WINDOWS_PROXY_STYLE
 #include <QWindowsStyle>
+#endif
 
 // KDE
-#include <KDebug>
 #include <KIconLoader>
 
 // Local
@@ -79,7 +82,7 @@ struct ThumbnailBarItemDelegatePrivate
     {
         mToggleSelectionButton = new ContextBarButton("list-add", mView->viewport());
         mToggleSelectionButton->hide();
-        QObject::connect(mToggleSelectionButton, SIGNAL(clicked(bool)), q, SLOT(toggleSelection()));
+        QObject::connect(mToggleSelectionButton, &ContextBarButton::clicked, q, &ThumbnailBarItemDelegate::toggleSelection);
     }
 
     void showToolTip(QHelpEvent* helpEvent)
@@ -247,6 +250,9 @@ ThumbnailBarItemDelegate::~ThumbnailBarItemDelegate()
     delete d;
 }
 
+//this is disabled by David Edmundson as I can't figure out how to port it
+//I hope with breeze being the default we don't want to start making our own styles anyway
+#ifdef WINDOWS_PROXY_STYLE
 /**
  * This proxy style makes it possible to override the value returned by
  * styleHint() which leads to not-so-nice results with some styles.
@@ -330,6 +336,7 @@ public:
         }
     }
 };
+#endif// WINDOWS_PROXY_STYLE
 
 typedef int (QSize::*QSizeDimension)() const;
 
@@ -441,8 +448,7 @@ ThumbnailBarView::ThumbnailBarView(QWidget* parent)
 {
     d->q = this;
     d->mTimeLine = new QTimeLine(SMOOTH_SCROLL_DURATION, this);
-    connect(d->mTimeLine, SIGNAL(frameChanged(int)),
-            SLOT(slotFrameChanged(int)));
+    connect(d->mTimeLine, &QTimeLine::frameChanged, this, &ThumbnailBarView::slotFrameChanged);
 
     d->mRowCount = 1;
     d->mOrientation = Qt::Vertical; // To pass value-has-changed check in setOrientation()
@@ -451,13 +457,17 @@ ThumbnailBarView::ThumbnailBarView(QWidget* parent)
     setObjectName(QLatin1String("thumbnailBarView"));
     setWrapping(true);
 
+    #ifdef WINDOWS_PROXY_STYLE
     d->mStyle = new ProxyStyle;
     setStyle(d->mStyle);
+    #endif
 }
 
 ThumbnailBarView::~ThumbnailBarView()
 {
+    #ifdef WINDOWS_PROXY_STYLE
     delete d->mStyle;
+    #endif
     delete d;
 }
 
