@@ -17,7 +17,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
-#include "jpegcontenttest.moc"
+#include "jpegcontenttest.h"
 #include <iostream>
 
 // Qt
@@ -27,8 +27,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QString>
 
 // KDE
-#include <qtest_kde.h>
-#include <KDebug>
+#include <qtest.h>
+#include <QDebug>
 #include <KFileMetaInfo>
 
 // Local
@@ -48,7 +48,7 @@ const int ORIENT6_WIDTH = 128; // This size is the size *after* orientation
 const int ORIENT6_HEIGHT = 256; // has been applied
 const QString ORIENT6_COMMENT = "a comment";
 
-QTEST_KDEMAIN(JpegContentTest, GUI)
+QTEST_MAIN(JpegContentTest)
 
 void JpegContentTest::initTestCase()
 {
@@ -258,9 +258,9 @@ void JpegContentTest::testLoadTruncated()
     QCOMPARE(int(content.orientation()), 6);
     QCOMPARE(content.comment() , ORIENT6_COMMENT);
     content.transform(Gwenview::VFLIP);
-    kWarning() << "# Next function should output errors about incomplete image" ;
+    qWarning() << "# Next function should output errors about incomplete image" ;
     content.save(TMP_FILE);
-    kWarning() << "#" ;
+    qWarning() << "#" ;
 }
 
 void JpegContentTest::testRawData()
